import React, { memo, createElement } from 'react';
import { Platform, View } from 'react-native';
import ReAnimated, { useAnimatedKeyboard, useAnimatedStyle } from 'react-native-reanimated';
import { useSafeAreaInsets } from 'react-native-safe-area-context';

function InputAccessoryView(props) {
  const {
    spaceHeight = 55,
    renderView = '',
    extraHeight = 0
  } = props;
  const keyboard = useAnimatedKeyboard();
  const insets = useSafeAreaInsets();
  const spaceStyle = useAnimatedStyle(() => {
    if (Platform.OS === 'ios') {
      return {
        height: keyboard.height.value + extraHeight
      };
    }

    return {
      height: keyboard.height.value - insets.bottom + extraHeight
    };
  }, [insets.bottom, extraHeight]);
  const translateStyle = useAnimatedStyle(() => ({
    opacity: keyboard.height.value === 0 ? 0 : 1
  }));
  return /*#__PURE__*/React.createElement(View, {
    style: {
      position: 'absolute',
      width: '100%',
      bottom: 0
    }
  }, /*#__PURE__*/React.createElement(ReAnimated.View, {
    style: [{
      height: spaceHeight,
      width: '100%'
    }, translateStyle]
  }, /*#__PURE__*/createElement(renderView)), /*#__PURE__*/React.createElement(ReAnimated.View, {
    style: spaceStyle
  }));
}

export default /*#__PURE__*/memo(InputAccessoryView);
//# sourceMappingURL=index.js.map